#
# spec file for package bpftool
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bpftool
VCS: https://src.suse.de/SLFO-pool/bpftool#de2b7e467090450f368772c68773e7824ca9b552ebe81efca8f1e4930f0bf6fd
Version:        7.3.0
Release:        slfo.1.1.25
Summary:        Tool for inspection and manipulation of BPF programs and maps
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://www.kernel.org/
Source0:        https://github.com/libbpf/bpftool/releases/download/v%{version}/bpftool-libbpf-v%{version}-sources.tar.gz
Patch0:         binutils-2.40.patch
BuildRequires:  binutils-devel
%if 0%{?suse_version} && 0%{?suse_version} <= 1500
%if 0%{?sle_version} < 150400
BuildRequires:  clang12-devel
%else
BuildRequires:  clang13-devel
%endif
%else
BuildRequires:  clang-devel
%endif
BuildRequires:  docutils
BuildRequires:  libcap-devel
BuildRequires:  libelf-devel
BuildRequires:  libzstd-devel

%description
bpftool allows for inspection and simple modification of BPF objects (programs
and maps) on the system.

%package bash-completion
Summary:        Bash completion for bpftool
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
bash command line completion support for bpftool.

%prep
%autosetup -p1 -n bpftool-libbpf-v%{version}-sources
sed -i -e 's/CFLAGS += -O2/CFLAGS = $(RPM_OPT_FLAGS)/' src/Makefile

%build
%make_build -C src V=1 \
    feature-reallocarray=1 \
    feature-libbfd-liberty=1 \
%if %(if gcc -lsframe -shared 2>/dev/null ; then echo 1 ; else echo 0; fi; )
    feature-libbfd-liberty-sframe=1 \
%endif
    feature-disassembler-four-args=1 \
    all
%make_build -C docs V=1 \
    man

%install
make -C src  V=1 install DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir}
make -C docs V=1 install DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir}

%files
%license LICENSE LICENSE.BSD-2-Clause LICENSE.GPL-2.0
%doc README.md CHECKPOINT-COMMIT BPF-CHECKPOINT-COMMIT
%{_sbindir}/bpftool
%{_mandir}/man?/*.gz

%files bash-completion
%{_datadir}/bash-completion/completions/bpftool

%changelog
* Tue Nov 28 2023 shung-hsi.yu@suse.com
- Update to version 7.3.0
  * deprecate keyword "dev" for specifying interface name, use
    offload_dev instead
  * support passing an interface name with xdpmeta_dev <ifname>
    with "prog load"
  * show more details information when displaying BPF links
  * show netfilter, tcx, and netkit information in the "net list"
  * support cgroup UNIX socket attach points
  * show inner map IDs (instead of raw values) with "map dump"
  * support LLVM's v4 instructions in the disassembler
  * fix JIT compiler global memory limit report for unprivileged
    users on aarch64
- Remove backported patches that have been included in v7.3.0
  * drop 0001-bpftool-use-a-local-copy-of-perf_event-to-fix-access.patch
  * drop 0002-bpftool-define-a-local-bpf_perf_link-to-fix-accessin.patch
  * drop 0003-bpftool-use-a-local-bpf_perf_event_value-to-fix-acce.patch
  * drop 0004-bpftool-Use-a-local-copy-of-BPF_LINK_TYPE_PERF_EVENT.patch
* Wed Mar 29 2023 msuchanek@suse.com
- Update to out-of-tree version 7.2.0
- Use release tarball that includes the specific copy of libbpf that is needed
  to build bpftool
- Fix build on Linux 5.14
  + 0001-bpftool-use-a-local-copy-of-perf_event-to-fix-access.patch
  + 0002-bpftool-define-a-local-bpf_perf_link-to-fix-accessin.patch
  + 0003-bpftool-use-a-local-bpf_perf_event_value-to-fix-acce.patch
  + 0004-bpftool-Use-a-local-copy-of-BPF_LINK_TYPE_PERF_EVENT.patch
* Wed Mar  1 2023 mliska@suse.cz
- Add -lzstd as libbfd is linked against the compression library.
* Wed Feb 22 2023 mliska@suse.cz
- Rebase binutils-2.40.patch for v6.2.
* Wed Feb 15 2023 mliska@suse.cz
- Add binutils-2.40.patch where we need to explicitly link against
  - lsframe. It's a workaround for an existing issue:
  https://github.com/libbpf/bpftool/issues/73.
* Fri Oct  7 2022 gmbr3@opensuse.org
- Move bash-completion to subpackage so it isn't installed when
  not needed
* Fri Apr  8 2022 dmueller@suse.com
- add rebuild subpackage to ensure rebuild in TW
* Thu Oct 14 2021 shung-hsi.yu@suse.com
- Enable libbfd feature to support dumping jited form of BPF programs
* Wed Jan  8 2020 lnussel@suse.de
- use optflags for building
- build and install man pages
* Thu May  9 2019 mrostecki@opensuse.org
- Initial release
